@@ -12,9 +12,18 @@ use constant abstract => 'convert axt to blocked fasta';
 sub opt_spec {
     return (
         [ "outfile|o=s", "Output filename, [stdout] for screen." ],
-        [ "length|l=i", "the threshold of alignment length, default is [1]", { default => 1 } ],
-        [ "tname|t=s", "target name, default is [target]", { default => "target" } ],
-        [ "qname|q=s", "query name, default is [query]",   { default => "query" } ],
+        [   "length|l=i",
+            "the threshold of alignment length, default is [1]",
+            { default => 1 }
+        ],
+        [   "tname|t=s",
+            "target name, default is [target]",
+            { default => "target" }
+        ],
+        [   "qname|q=s",
+            "query name, default is [query]",
+            { default => "query" }
+        ],
         [   "size|s=s",
             "query chr.sizes. Without this file, positions of negtive strand of query will be wrong",
         ],
@@ -24,21 +33,24 @@ sub opt_spec {
 sub usage_desc {
     my $self = shift;
     my $desc = $self->SUPER::usage_desc;    # "%c COMMAND %o"
-    $desc .= " <infile>";
+    $desc .= " <infile> [more infiles]";
     return $desc;
 }
 
 sub description {
     my $desc;
-    $desc .= "Convert UCSC axt pairwise alignment file to blocked fasta file.\n";
-    $desc .= "\t<infiles> are paths to axt files, .axt.gz is supported\n";
+    $desc
+        .= "Convert UCSC axt pairwise alignment file to blocked fasta file.\n";
+    $desc .= "\tinfiles are paths to axt files, .axt.gz is supported\n";
     return $desc;
 }
 
 sub validate_args {
     my ( $self, $opt, $args ) = @_;
 
-    $self->usage_error("This command need one or more input files.") unless @{$args};
+    if ( !@{$args} ) {
+        $self->usage_error("This command need one or more input files.");
+    }
     for ( @{$args} ) {
         if ( !Path::Tiny::path($_)->is_file ) {
             $self->usage_error("The input file [$_] doesn't exist.");
@@ -98,19 +110,25 @@ sub execute {
                 next;
             }
             elsif ( ( $line eq '' or $line =~ /^\s+$/ ) and $content ne '' ) {
-                my $info_refs = App::Fasops::Common::parse_axt_block( $content, $length_of );
+                my $info_refs = App::Fasops::Common::parse_axt_block( $content,
+                    $length_of );
                 $content = '';
 
-                next if App::Fasops::Common::seq_length( $info_refs->[0]{seq} ) < $opt->{length};
-                next if App::Fasops::Common::seq_length( $info_refs->[1]{seq} ) < $opt->{length};
+                next
+                    if App::Fasops::Common::seq_length( $info_refs->[0]{seq} )
+                    < $opt->{length};
+                next
+                    if App::Fasops::Common::seq_length( $info_refs->[1]{seq} )
+                    < $opt->{length};
 
                 $info_refs->[0]{name} = $opt->{tname};
-                $info_refs->[1]{name}  = $opt->{qname};
+                $info_refs->[1]{name} = $opt->{qname};
 
-                for my $i (0, 1) {
+                for my $i ( 0, 1 ) {
                     my $info = $info_refs->[$i];
-                    printf {$out_fh} ">%s\n", App::RL::Common::encode_header($info);
-                    printf {$out_fh} "%s\n",  $info->{seq};
+                    printf {$out_fh} ">%s\n",
+                        App::RL::Common::encode_header($info);
+                    printf {$out_fh} "%s\n", $info->{seq};
                 }
                 print {$out_fh} "\n";
             }
