@@ -7,7 +7,8 @@ use App::Fasops -command;
 use App::RL::Common;
 use App::Fasops::Common;
 
-use constant abstract => 'scan blocked fasta files and output links between pieces';
+use constant abstract =>
+    'scan blocked fasta files and output links between pieces';
 
 sub opt_spec {
     return ( [ "outfile|o=s", "Output filename. [stdout] for screen." ], );
@@ -16,21 +17,24 @@ sub opt_spec {
 sub usage_desc {
     my $self = shift;
     my $desc = $self->SUPER::usage_desc;    # "%c COMMAND %o"
-    $desc .= " <infiles>";
+    $desc .= " <infile> [more infiles]";
     return $desc;
 }
 
 sub description {
     my $desc;
     $desc .= ucfirst(abstract) . ".\n";
-    $desc .= "\t<infiles> are paths to blocked fasta files, .fas.gz is supported.\n";
+    $desc
+        .= "\tinfiles are paths to blocked fasta files, .fas.gz is supported.\n";
     return $desc;
 }
 
 sub validate_args {
     my ( $self, $opt, $args ) = @_;
 
-    $self->usage_error("This command need one or more input files.") unless @{$args};
+    if ( !@{$args} ) {
+        $self->usage_error("This command need one or more input files.");
+    }
     for ( @{$args} ) {
         if ( !Path::Tiny::path($_)->is_file ) {
             $self->usage_error("The input file [$_] doesn't exist.");
@@ -66,8 +70,10 @@ sub execute {
 
                 for ( my $i = 0; $i <= $#names; $i++ ) {
                     for ( my $j = $i + 1; $j <= $#names; $j++ ) {
-                        my $header1 = App::RL::Common::encode_header( $info_of->{ $names[$i] }, 1 );
-                        my $header2 = App::RL::Common::encode_header( $info_of->{ $names[$j] }, 1 );
+                        my $header1 = App::RL::Common::encode_header(
+                            $info_of->{ $names[$i] }, 1 );
+                        my $header2 = App::RL::Common::encode_header(
+                            $info_of->{ $names[$j] }, 1 );
                         push @links, [ $header1, $header2 ];
                     }
                 }
